# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.applicationmodel as windows_applicationmodel
import winrt.windows.applicationmodel.activation as windows_applicationmodel_activation
import winrt.windows.data.xml.dom as windows_data_xml_dom
import winrt.windows.devices.printers as windows_devices_printers
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.graphics.printing.printticket as windows_graphics_printing_printticket
import winrt.windows.system as windows_system
import winrt.windows.ui as windows_ui
import winrt.windows.ui.shell as windows_ui_shell

from winrt.windows.graphics.printing.printsupport import IppCommunicationErrorKind, IppPrinterCommunicationKind, SettingsLaunchKind, WorkflowPrintTicketValidationStatus, XpsImageQuality

Self = typing.TypeVar('Self')

@typing.final
class PrintSupportCommunicationErrorDetectedEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.Graphics.Printing.PrintSupport.PrintSupportCommunicationErrorDetectedEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationConfiguration Windows.Graphics.Printing.PrintSupport.PrintSupportCommunicationErrorDetectedEventArgs::get_CommunicationConfiguration()
    @_property
    def communication_configuration(self) -> PrintSupportIppCommunicationConfiguration: ...
    # Windows.Graphics.Printing.PrintSupport.IppCommunicationErrorKind Windows.Graphics.Printing.PrintSupport.PrintSupportCommunicationErrorDetectedEventArgs::get_ErrorKind()
    @_property
    def error_kind(self) -> IppCommunicationErrorKind: ...
    # Windows.Foundation.HResult Windows.Graphics.Printing.PrintSupport.PrintSupportCommunicationErrorDetectedEventArgs::get_ExtendedError()
    @_property
    def extended_error(self) -> windows_foundation.HResult: ...

@typing.final
class PrintSupportExtensionSession(winrt.system.Object):
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::Start()
    def start(self) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::add_PrintDeviceCapabilitiesChanged(Windows.Foundation.TypedEventHandler`2<Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession,Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs>)
    def add_print_device_capabilities_changed(self, handler: windows_foundation.TypedEventHandler[PrintSupportExtensionSession, PrintSupportPrintDeviceCapabilitiesChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::remove_PrintDeviceCapabilitiesChanged(Windows.Foundation.EventRegistrationToken)
    def remove_print_device_capabilities_changed(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::add_PrintTicketValidationRequested(Windows.Foundation.TypedEventHandler`2<Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession,Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketValidationRequestedEventArgs>)
    def add_print_ticket_validation_requested(self, handler: windows_foundation.TypedEventHandler[PrintSupportExtensionSession, PrintSupportPrintTicketValidationRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::remove_PrintTicketValidationRequested(Windows.Foundation.EventRegistrationToken)
    def remove_print_ticket_validation_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::add_PrinterSelected(Windows.Foundation.TypedEventHandler`2<Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession,Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs>)
    def add_printer_selected(self, handler: windows_foundation.TypedEventHandler[PrintSupportExtensionSession, PrintSupportPrinterSelectedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::remove_PrinterSelected(Windows.Foundation.EventRegistrationToken)
    def remove_printer_selected(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::add_CommunicationErrorDetected(Windows.Foundation.TypedEventHandler`2<Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession,Windows.Graphics.Printing.PrintSupport.PrintSupportCommunicationErrorDetectedEventArgs>)
    def add_communication_error_detected(self, handler: windows_foundation.TypedEventHandler[PrintSupportExtensionSession, PrintSupportCommunicationErrorDetectedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::remove_CommunicationErrorDetected(Windows.Foundation.EventRegistrationToken)
    def remove_communication_error_detected(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Devices.Printers.IppPrintDevice Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession::get_Printer()
    @_property
    def printer(self) -> windows_devices_printers.IppPrintDevice: ...

@typing.final
class PrintSupportExtensionTriggerDetails(winrt.system.Object):
    # Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionSession Windows.Graphics.Printing.PrintSupport.PrintSupportExtensionTriggerDetails::get_Session()
    @_property
    def session(self) -> PrintSupportExtensionSession: ...

@typing.final
class PrintSupportIppCommunicationConfiguration(winrt.system.Object):
    # System.Boolean Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationConfiguration::get_CanModifyTimeouts()
    @_property
    def can_modify_timeouts(self) -> bool: ...
    # Windows.Graphics.Printing.PrintSupport.IppPrinterCommunicationKind Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationConfiguration::get_CommunicationKind()
    @_property
    def communication_kind(self) -> IppPrinterCommunicationKind: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationConfiguration::get_IppAttributeTimeouts()
    @_property
    def ipp_attribute_timeouts(self) -> PrintSupportIppCommunicationTimeouts: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationConfiguration::get_IppJobTimeouts()
    @_property
    def ipp_job_timeouts(self) -> PrintSupportIppCommunicationTimeouts: ...

@typing.final
class PrintSupportIppCommunicationTimeouts(winrt.system.Object):
    # Windows.Foundation.TimeSpan Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts::get_SendTimeout()
    @_property
    def send_timeout(self) -> datetime.timedelta: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts::put_SendTimeout(Windows.Foundation.TimeSpan)
    @send_timeout.setter
    def send_timeout(self, value: datetime.timedelta) -> None: ...
    # Windows.Foundation.TimeSpan Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts::get_ReceiveTimeout()
    @_property
    def receive_timeout(self) -> datetime.timedelta: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts::put_ReceiveTimeout(Windows.Foundation.TimeSpan)
    @receive_timeout.setter
    def receive_timeout(self, value: datetime.timedelta) -> None: ...
    # Windows.Foundation.TimeSpan Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts::get_ConnectTimeout()
    @_property
    def connect_timeout(self) -> datetime.timedelta: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationTimeouts::put_ConnectTimeout(Windows.Foundation.TimeSpan)
    @connect_timeout.setter
    def connect_timeout(self, value: datetime.timedelta) -> None: ...

@typing.final
class PrintSupportMxdcImageQualityConfiguration(winrt.system.Object):
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_TextOutputQuality()
    @_property
    def text_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_TextOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @text_output_quality.setter
    def text_output_quality(self, value: XpsImageQuality) -> None: ...
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_PhotographicOutputQuality()
    @_property
    def photographic_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_PhotographicOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @photographic_output_quality.setter
    def photographic_output_quality(self, value: XpsImageQuality) -> None: ...
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_NormalOutputQuality()
    @_property
    def normal_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_NormalOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @normal_output_quality.setter
    def normal_output_quality(self, value: XpsImageQuality) -> None: ...
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_HighOutputQuality()
    @_property
    def high_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_HighOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @high_output_quality.setter
    def high_output_quality(self, value: XpsImageQuality) -> None: ...
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_FaxOutputQuality()
    @_property
    def fax_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_FaxOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @fax_output_quality.setter
    def fax_output_quality(self, value: XpsImageQuality) -> None: ...
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_DraftOutputQuality()
    @_property
    def draft_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_DraftOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @draft_output_quality.setter
    def draft_output_quality(self, value: XpsImageQuality) -> None: ...
    # Windows.Graphics.Printing.PrintSupport.XpsImageQuality Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::get_AutomaticOutputQuality()
    @_property
    def automatic_output_quality(self) -> XpsImageQuality: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration::put_AutomaticOutputQuality(Windows.Graphics.Printing.PrintSupport.XpsImageQuality)
    @automatic_output_quality.setter
    def automatic_output_quality(self, value: XpsImageQuality) -> None: ...

@typing.final
class PrintSupportPrintDeviceCapabilitiesChangedEventArgs(winrt.system.Object):
    # Windows.Data.Xml.Dom.XmlDocument Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::GetCurrentPrintDeviceCapabilities()
    def get_current_print_device_capabilities(self) -> windows_data_xml_dom.XmlDocument: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::GetCurrentPrintDeviceResources()
    def get_current_print_device_resources(self) -> windows_data_xml_dom.XmlDocument: ...
    # Windows.Foundation.Deferral Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::SetPrintDeviceCapabilitiesUpdatePolicy(Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesUpdatePolicy)
    def set_print_device_capabilities_update_policy(self, update_policy: PrintSupportPrintDeviceCapabilitiesUpdatePolicy, /) -> None: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::SetSupportedPdlPassthroughContentTypes(Windows.Foundation.Collections.IIterable`1<System.String>)
    def set_supported_pdl_passthrough_content_types(self, supported_pdl_content_types: typing.Iterable[str], /) -> None: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::UpdatePrintDeviceCapabilities(Windows.Data.Xml.Dom.XmlDocument)
    def update_print_device_capabilities(self, updated_pdc: windows_data_xml_dom.XmlDocument, /) -> None: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::UpdatePrintDeviceResources(Windows.Data.Xml.Dom.XmlDocument)
    def update_print_device_resources(self, updated_pdr: windows_data_xml_dom.XmlDocument, /) -> None: ...
    # System.String Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::get_ResourceLanguage()
    @_property
    def resource_language(self) -> str: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportIppCommunicationConfiguration Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::get_CommunicationConfiguration()
    @_property
    def communication_configuration(self) -> PrintSupportIppCommunicationConfiguration: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportMxdcImageQualityConfiguration Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesChangedEventArgs::get_MxdcImageQualityConfiguration()
    @_property
    def mxdc_image_quality_configuration(self) -> PrintSupportMxdcImageQualityConfiguration: ...

@typing.final
class PrintSupportPrintDeviceCapabilitiesUpdatePolicy_Static(winrt._winrt.IInspectable_Static):
    # Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesUpdatePolicy Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesUpdatePolicy::CreatePeriodicRefresh(Windows.Foundation.TimeSpan)
    def create_periodic_refresh(cls, update_period: datetime.timedelta, /) -> PrintSupportPrintDeviceCapabilitiesUpdatePolicy: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesUpdatePolicy Windows.Graphics.Printing.PrintSupport.PrintSupportPrintDeviceCapabilitiesUpdatePolicy::CreatePrintJobRefresh(System.UInt32)
    def create_print_job_refresh(cls, number_of_jobs: winrt.system.UInt32, /) -> PrintSupportPrintDeviceCapabilitiesUpdatePolicy: ...

@typing.final
class PrintSupportPrintDeviceCapabilitiesUpdatePolicy(winrt.system.Object, metaclass=PrintSupportPrintDeviceCapabilitiesUpdatePolicy_Static):
    pass

@typing.final
class PrintSupportPrintTicketElement(winrt.system.Object):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.String Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketElement::get_NamespaceUri()
    @_property
    def namespace_uri(self) -> str: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketElement::put_NamespaceUri(System.String)
    @namespace_uri.setter
    def namespace_uri(self, value: str) -> None: ...
    # System.String Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketElement::get_LocalName()
    @_property
    def local_name(self) -> str: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketElement::put_LocalName(System.String)
    @local_name.setter
    def local_name(self, value: str) -> None: ...

@typing.final
class PrintSupportPrintTicketValidationRequestedEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketValidationRequestedEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketValidationRequestedEventArgs::SetPrintTicketValidationStatus(Windows.Graphics.Printing.PrintSupport.WorkflowPrintTicketValidationStatus)
    def set_print_ticket_validation_status(self, status: WorkflowPrintTicketValidationStatus, /) -> None: ...
    # Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketValidationRequestedEventArgs::get_PrintTicket()
    @_property
    def print_ticket(self) -> windows_graphics_printing_printticket.WorkflowPrintTicket: ...

@typing.final
class PrintSupportPrinterSelectedEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::SetAdaptiveCard(Windows.UI.Shell.IAdaptiveCard)
    def set_adaptive_card(self, adaptive_card: windows_ui_shell.IAdaptiveCard, /) -> None: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::SetAdditionalFeatures(Windows.Foundation.Collections.IIterable`1<Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketElement>)
    def set_additional_features(self, features: typing.Iterable[PrintSupportPrintTicketElement], /) -> None: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::SetAdditionalParameters(Windows.Foundation.Collections.IIterable`1<Windows.Graphics.Printing.PrintSupport.PrintSupportPrintTicketElement>)
    def set_additional_parameters(self, parameters: typing.Iterable[PrintSupportPrintTicketElement], /) -> None: ...
    # Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::get_PrintTicket()
    @_property
    def print_ticket(self) -> windows_graphics_printing_printticket.WorkflowPrintTicket: ...
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::put_PrintTicket(Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket)
    @print_ticket.setter
    def print_ticket(self, value: windows_graphics_printing_printticket.WorkflowPrintTicket) -> None: ...
    # System.UInt32 Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::get_AllowedAdditionalFeaturesAndParametersCount()
    @_property
    def allowed_additional_features_and_parameters_count(self) -> winrt.system.UInt32: ...
    # Windows.ApplicationModel.AppInfo Windows.Graphics.Printing.PrintSupport.PrintSupportPrinterSelectedEventArgs::get_SourceAppInfo()
    @_property
    def source_app_info(self) -> windows_applicationmodel.AppInfo: ...

@typing.final
class PrintSupportSessionInfo(winrt.system.Object):
    # Windows.Devices.Printers.IppPrintDevice Windows.Graphics.Printing.PrintSupport.PrintSupportSessionInfo::get_Printer()
    @_property
    def printer(self) -> windows_devices_printers.IppPrintDevice: ...
    # Windows.ApplicationModel.AppInfo Windows.Graphics.Printing.PrintSupport.PrintSupportSessionInfo::get_SourceAppInfo()
    @_property
    def source_app_info(self) -> windows_applicationmodel.AppInfo: ...

@typing.final
class PrintSupportSettingsActivatedEventArgs(winrt.system.Object, windows_applicationmodel_activation.IActivatedEventArgsWithUser, windows_applicationmodel_activation.IActivatedEventArgs):
    # Windows.Foundation.Deferral Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Activation.ActivationKind Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::get_Kind()
    @_property
    def kind(self) -> windows_applicationmodel_activation.ActivationKind: ...
    # Windows.ApplicationModel.Activation.ApplicationExecutionState Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::get_PreviousExecutionState()
    @_property
    def previous_execution_state(self) -> windows_applicationmodel_activation.ApplicationExecutionState: ...
    # Windows.ApplicationModel.Activation.SplashScreen Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::get_SplashScreen()
    @_property
    def splash_screen(self) -> windows_applicationmodel_activation.SplashScreen: ...
    # Windows.System.User Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::get_User()
    @_property
    def user(self) -> windows_system.User: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsUISession Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::get_Session()
    @_property
    def session(self) -> PrintSupportSettingsUISession: ...
    # Windows.UI.WindowId Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsActivatedEventArgs::get_OwnerWindowId()
    @_property
    def owner_window_id(self) -> windows_ui.WindowId: ...

@typing.final
class PrintSupportSettingsUISession(winrt.system.Object):
    # System.Void Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsUISession::UpdatePrintTicket(Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket)
    def update_print_ticket(self, print_ticket: windows_graphics_printing_printticket.WorkflowPrintTicket, /) -> None: ...
    # System.String Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsUISession::get_DocumentTitle()
    @_property
    def document_title(self) -> str: ...
    # Windows.Graphics.Printing.PrintSupport.SettingsLaunchKind Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsUISession::get_LaunchKind()
    @_property
    def launch_kind(self) -> SettingsLaunchKind: ...
    # Windows.Graphics.Printing.PrintSupport.PrintSupportSessionInfo Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsUISession::get_SessionInfo()
    @_property
    def session_info(self) -> PrintSupportSessionInfo: ...
    # Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket Windows.Graphics.Printing.PrintSupport.PrintSupportSettingsUISession::get_SessionPrintTicket()
    @_property
    def session_print_ticket(self) -> windows_graphics_printing_printticket.WorkflowPrintTicket: ...

